@@ -9,11 +9,13 @@ sub register {
     my($self, $context) = @_;
     $context->register_hook(
         $self,
-        'publish.init'        => \&initialize,
-        'publish.entry.fixup' => \&add_entry,
+        'plugin.init'   => \&initialize,
+        'publish.entry' => \&add_entry,
     );
 }
 
+sub rule_hook { 'publish.entry' }
+
 sub initialize {
     my ($self, $context, $args) = @_;
     $self->{delicious} = Net::Delicious->new({
