@@ -116,11 +116,11 @@ sub sync {
 
     # catch bad XML feed by Bloglines
     eval {
-        @updates = $self->{bloglines}->getitems(0, $mark_read);
+        @updates = $self->{bloglines}->getitems(0, 0);
     };
 
     if ($@) {
-        $context->log(warn => "Bloglines Sync API returned bad XML. fallbacks to loop mode");
+        $context->log(warn => "Bloglines Sync API returned bad XML. fallbacks to loop mode: $@");
         my @feeds = $self->{bloglines}->listsubs()->feeds;
         for my $feed (@feeds) {
             if ($feed->{BloglinesUnread}) {
@@ -128,6 +128,11 @@ sub sync {
                 push @updates, eval { $self->{bloglines}->getitems($feed->{BloglinesSubId}, $mark_read) };
             }
         }
+    } elsif ($mark_read) {
+        # no error found with XML ... call the API again to mark read
+        eval {
+            @updates = $self->{bloglines}->getitems(0, $mark_read);
+        };
     }
 
     $context->log(info => scalar(@updates) . " feed(s) updated.");
